@@ -588,14 +588,19 @@ class NormalRegressor(BaseEstimator, RegressorMixin):
         except NotFittedError:
             self._initialize_prior(X)
 
-        cov = np.linalg.inv(self.cov_inv_)
+        cov = solve(
+            self.cov_inv_, np.eye(self.n_features_), check_finite=False, assume_a="pos"
+        )
         rv_gen = partial(
             multivariate_normal.rvs, size=size, random_state=self.random_state_
         )
 
-        samples = np.atleast_2d(rv_gen(self.coef_, cov))  # type: ignore
+        samples = np.atleast_1d(rv_gen(self.coef_, cov))  # type: ignore
 
-        return np.einsum("ij,...j", X, samples)  # type: ignore
+        if self.n_features_ == 1:
+            samples = np.expand_dims(samples, -1)
+
+        return np.atleast_2d(samples @ X.T)  # type: ignore
 
     def decay(self, X: NDArray[Any]) -> None:
         """
@@ -606,14 +611,12 @@ class NormalRegressor(BaseEstimator, RegressorMixin):
 
         prior_decay = self.learning_rate ** len(X)
 
-        # Decay the prior without making an update
+        # Decay the prior without making an update. Because we're only
+        # increasing the prior variance, we do not need to update the
+        # mean.
         cov_inv = prior_decay * self.cov_inv_
-        # Calculate the posterior mean
-        cov = np.linalg.inv(cov_inv)
-        coef = cov @ (prior_decay * self.cov_inv_ @ self.coef_)
 
         self.cov_inv_ = cov_inv
-        self.coef_ = coef
 
 
 class NormalInverseGammaRegressor(NormalRegressor):
@@ -806,13 +809,17 @@ class NormalInverseGammaRegressor(NormalRegressor):
         except NotFittedError:
             self._initialize_prior(X)
 
-        shape = (self.b_ / self.a_) * np.linalg.inv(self.cov_inv_)
+        extra_var = self.b_ / self.a_ * np.eye(self.n_features_)
+        shape = solve(self.cov_inv_, extra_var, check_finite=False, assume_a="pos")
+
         df = 2 * self.a_
         rv_gen = partial(multivariate_t.rvs, size=size, random_state=self.random_state_)
 
-        samples = np.atleast_2d(rv_gen(self.coef_, shape, df))  # type: ignore
+        samples = np.atleast_1d(rv_gen(self.coef_, shape, df))  # type: ignore
+        if self.n_features_ == 1:
+            samples = np.expand_dims(samples, -1)
 
-        return np.einsum("ij,...j", X, samples)  # type: ignore
+        return np.atleast_2d(samples @ X.T)  # type: ignore
 
     def decay(self, X: NDArray[Any]):
         """
@@ -827,16 +834,14 @@ class NormalInverseGammaRegressor(NormalRegressor):
 
         prior_decay = self.learning_rate ** len(X)
 
+        # decay only increases the variance, so we only need to update the
+        # inverse covariance matrix, a_, and b_
         V_n = prior_decay * self.cov_inv_
 
-        V_n_inv = np.linalg.inv(V_n)
-        m_n = V_n_inv @ (prior_decay * self.cov_inv_ @ self.coef_)
-
         a_n = prior_decay * self.a_
 
         b_n = prior_decay * self.b_
 
         self.cov_inv_ = V_n
-        self.coef_ = m_n
         self.a_ = a_n
         self.b_ = b_n
